@@ -3,29 +3,35 @@ from types import FrameType
 import typing
 import uvicorn
 import socket
+import logging
 
-
+logger = logging.getLogger(__name__)
 ThandleExitCallbacks = list[typing.Callable[[], typing.Any]]
 
 
 class UvicornServer(uvicorn.Server):
-    instance: UvicornServer
+    _instance: UvicornServer
 
     def __init__(self, config: uvicorn.Config) -> None:
         super().__init__(config)
         self._handle_exit_callbacks: ThandleExitCallbacks = []
 
+    @classmethod
+    def get_instance(cls) -> UvicornServer:
+        if not hasattr(cls, "_instance"):
+            raise RuntimeError("UvicornServer singleton not created")
+        return cls._instance
+
     @classmethod
     def create_singleton(
         cls, config: uvicorn.Config, handle_exit_callbacks: ThandleExitCallbacks
     ) -> None:
-        cls.instance = cls(config=config)
+        cls._instance = cls(config=config)
         for callback in handle_exit_callbacks:
-            cls.instance.on_handle_exit(callback)
+            cls._instance.on_handle_exit(callback)
 
     def run(self, sockets: typing.Optional[list[socket.socket]] = None) -> None:
-        self.instance = self
-
+        self._instance = self
         super().run()
 
     def on_handle_exit(self, callback: typing.Callable[[], typing.Any]):
@@ -33,5 +39,8 @@ class UvicornServer(uvicorn.Server):
 
     def handle_exit(self, sig: int, frame: FrameType | None) -> None:
         for callback in self._handle_exit_callbacks:
-            callback()
+            try:
+                callback()
+            except Exception as e:
+                logger.exception("Exception in handle_exit callback: %s", e)
         return super().handle_exit(sig, frame)
