@@ -1,4 +1,4 @@
-from fastapi import FastAPI
+from fastapi import APIRouter
 from fastapi.responses import FileResponse
 
 from instaui.fastapi_server import resource
@@ -7,12 +7,12 @@ from instaui.fastapi_server import resource
 URL = f"{resource.URL}/{{hash_part:path}}/{{file_name:path}}"
 
 
-def create_router(app: FastAPI):
-    _dependency_handler(app)
+def create_router(router: APIRouter):
+    _dependency_handler(router)
 
 
-def _dependency_handler(app: FastAPI):
-    @app.get(URL)
+def _dependency_handler(router: APIRouter):
+    @router.get(URL)
     def _(hash_part: str, file_name: str) -> FileResponse:
         hash_part_with_extend_paths = hash_part.split("/", maxsplit=1)
         hash_part = hash_part_with_extend_paths[0]
