@@ -1,19 +1,21 @@
 from __future__ import annotations
 from contextlib import contextmanager
 import inspect
-import os
 import multiprocessing
+import os
+import uvicorn
+from uvicorn.supervisors import ChangeReload
 from pathlib import Path
-from typing import Any, Callable, Optional, Set, Union
+from typing import Any, Callable, Final, Optional, Set, Union
+from enum import Enum
 import __main__
 
-from fastapi import FastAPI
-from fastapi import Request
+from ._uvicorn import UvicornServer
+
+from fastapi import FastAPI, Request, APIRouter
 from fastapi.middleware.gzip import GZipMiddleware
 from fastapi.staticfiles import StaticFiles
 from fastapi.responses import HTMLResponse
-import uvicorn
-from uvicorn.supervisors import ChangeReload
 import itertools
 
 from instaui.html_tools import to_config_data
@@ -32,11 +34,10 @@ from . import event_router
 from . import watch_router
 from . import debug_mode_router
 from .middlewares import RequestContextMiddleware, NoCacheDebugModeMiddleware
-from ._uvicorn import UvicornServer
 from . import resource
 from instaui.version import __version__ as _INSTA_VERSION
 
-APP_IMPORT_STRING = "instaui.fastapi_server.server:Server._instance.app"
+APP_IMPORT_STRING: Final[str] = "instaui.fastapi_server.server:Server.app"
 
 
 INSTAUI_STATIC_URL = f"/_instaui_{_INSTA_VERSION}/static"
@@ -54,7 +55,7 @@ FAVICON_LINK = _cal_static_link(consts.FAVICON_PATH)
 
 
 class Server:
-    _instance: Optional[Server] = None
+    app: Optional[FastAPI] = None
 
     def __init__(
         self,
@@ -62,33 +63,26 @@ class Server:
         caller_file_path: Path,
         use_gzip: Union[int, bool] = True,
     ):
-        debug_mode = get_launch_collector().debug_mode
+        self._debug_mode = get_launch_collector().debug_mode
         self._caller_file_path = caller_file_path
-        self.app = FastAPI()
-        self.app.add_middleware(RequestContextMiddleware)
-        if debug_mode:
-            self.app.add_middleware(NoCacheDebugModeMiddleware)
+        self._use_gzip = use_gzip
+        self._use_fns: list[Callable[[FastAPI], None]] = []
 
-        if use_gzip:
-            self.app.add_middleware(
-                GZipMiddleware,
-                minimum_size=use_gzip if isinstance(use_gzip, int) else 500,
-            )
+        self._router = APIRouter(tags=["InstaUI"])
 
-        dependency_router.create_router(self.app)
-        event_router.create_router(self.app)
-        watch_router.create_router(self.app)
-        debug_mode_router.create_router(self.app)
-
-        self.try_add_user_assets(self.app)
-        self.add_instaui_static(self.app)
+        dependency_router.create_router(self._router)
+        event_router.create_router(self._router)
+        watch_router.create_router(self._router)
+        debug_mode_router.create_router(self._router)
 
         for page_info in get_launch_collector()._page_router.values():
             self.register_page(page_info)
 
         self._registered_static_routes: Set[str] = set()
 
-        Server._instance = self
+    @property
+    def router(self) -> APIRouter:
+        return self.app.router if self.app else self._router
 
     def register_page(self, info: PageInfo):
         is_async = inspect.iscoroutinefunction(info.func)
@@ -97,7 +91,7 @@ class Server:
 
         if is_async:
 
-            @self.app.get(info.path)
+            @self.router.get(info.path)
             async def _(request: Request):
                 self._update_page_info(request, info)
                 with _execute_request_lifespans():
@@ -111,7 +105,7 @@ class Server:
 
         else:
 
-            @self.app.get(info.path)
+            @self.router.get(info.path)
             def _(request: Request):
                 self._update_page_info(request, info)
                 with _execute_request_lifespans():
@@ -246,15 +240,18 @@ class Server:
         app._query_params = dict(request.query_params)
 
     def _remove_route(self, path: str) -> None:
-        self.app.routes[:] = [
-            r for r in self.app.routes if getattr(r, "path", None) != path
+        self.router.routes[:] = [
+            r for r in self.router.routes if getattr(r, "path", None) != path
         ]
 
     def try_close_server(self):
-        UvicornServer.instance.should_exit = True
+        assert UvicornServer.get_instance() is not None, (
+            "Uvicorn server does not exist. Cannot attempt to shut down service in debug mode or reload mode"
+        )
+        UvicornServer.get_instance().should_exit = True
 
     def use(self, fn: Callable[[FastAPI], None]):
-        fn(self.app)
+        self._use_fns.append(fn)
         return self
 
     def run(
@@ -270,6 +267,12 @@ class Server:
         uds: str | None = None,
         **kwargs: Any,
     ):
+        reload = self._debug_mode or reload
+
+        app = FastAPI()
+        Server.app = app
+        self._setup_fastapi_app(app)
+
         if multiprocessing.current_process().name != "MainProcess":
             return
 
@@ -277,7 +280,7 @@ class Server:
             reload = False
 
         config = uvicorn.Config(
-            APP_IMPORT_STRING if reload else self.app,
+            APP_IMPORT_STRING if reload else app,
             host=host,
             port=port,
             reload=reload,
@@ -293,16 +296,68 @@ class Server:
         UvicornServer.create_singleton(config, [debug_mode_router.when_server_reload])
 
         if config.should_reload:
-            ChangeReload(config, target=UvicornServer.instance.run, sockets=[]).run()
+            ChangeReload(
+                config, target=UvicornServer.get_instance().run, sockets=[]
+            ).run()
         else:
-            UvicornServer.instance.run()
+            UvicornServer.get_instance().run()
 
         if config.uds:
             os.remove(config.uds)  # pragma: py-win32
 
-    def run_with(self, app):
+    def run_with(
+        self,
+        app: FastAPI,
+        *,
+        prefix: str = "/instaui",
+        tags: Optional[list[str | Enum]] = None,
+        dependencies: Optional[list[Any]] = None,
+        responses: Optional[dict[int | str, dict[str, Any]]] = None,
+    ):
+        """
+        Mounts the InstaUI interface onto a FastAPI application with configurable routing.
+
+        Args:
+            app (FastAPI): The FastAPI application instance to mount InstaUI onto.
+            prefix (str, optional): The URL prefix for InstaUI routes. Defaults to "/instaui".
+            tags (Optional[list[str | Enum]], optional): OpenAPI tags for InstaUI endpoints.
+            dependencies (Optional[list[Any]], optional): Dependencies to apply to all InstaUI routes.
+            responses (Optional[dict[int | str, dict[str, Any]]], optional): Additional response definitions for InstaUI endpoints.
+
+        Example:
+        .. code-block:: python
+            app = FastAPI()
+
+            @app.get("/")
+            def index():
+                return {"message": "Hello World"}
+
+            # www.example.com/instaui/ -> InstaUI interface
+            @ui.page("/")
+            def index_page():
+                ui.text("instaui page")
+
+            ui.server().run_with(app)
+
+
+            if __name__ == "__main__":
+                import uvicorn
+                uvicorn.run(app, host="127.0.0.1", port=8080)
+
+        """
         assert isinstance(app, FastAPI), "app must be a FastAPI instance"
 
+        if tags is not None:
+            self._router.tags = tags
+        if dependencies:
+            self._router.dependencies = dependencies
+        if responses:
+            self._router.responses = responses
+
+        self._setup_fastapi_app(app, include_router=False)
+        app.include_router(self._router, prefix=prefix)
+        return self._router
+
     @staticmethod
     def add_instaui_static(app: FastAPI):
         app.mount(
@@ -322,6 +377,26 @@ class Server:
             f"User assets directory found: {assets_dir} : mount to {INSTAUI_USER_ASSETS_URL}"
         )
 
+    def _setup_fastapi_app(self, app: FastAPI, *, include_router=True):
+        app.add_middleware(RequestContextMiddleware)
+        if self._debug_mode:
+            app.add_middleware(NoCacheDebugModeMiddleware)
+
+        if self._use_gzip:
+            app.add_middleware(
+                GZipMiddleware,
+                minimum_size=self._use_gzip if isinstance(self._use_gzip, int) else 500,
+            )
+
+        for fn in self._use_fns:
+            fn(app)
+
+        self.try_add_user_assets(app)
+        self.add_instaui_static(app)
+
+        if include_router:
+            app.include_router(self._router)
+
 
 def _split_args(args: str):
     return [a.strip() for a in args.split(",")]
