@@ -41,6 +41,7 @@ __all__ = [
     "use_tailwind",
     "use_page_title",
     "use_language",
+    "unwrap_reactive",
     "directive",
     "vif",
     "page",
@@ -55,6 +56,7 @@ __all__ = [
     "grid",
     "container",
     "text",
+    "link",
     "heading",
     "watch",
     "vue_watch",
@@ -96,6 +98,7 @@ from instaui.vars.session_storage import session_storage
 from instaui.vars.use_dark import use_dark
 from instaui.vars.use_page_title import use_page_title
 from instaui.vars.use_language import use_language
+from instaui.vars.unwrap_reactive import unwrap_reactive
 from instaui.page_state import PageState
 from instaui.vars.vfor_item import TVForItem, TVForIndex
 from instaui.vars.element_ref import ElementRef as element_ref, run_element_method
@@ -130,6 +133,7 @@ from instaui.components.layout.flex import (
 from instaui.components.layout.grid import Grid as grid
 from instaui.components.layout.container import Container as container
 from instaui.components.text import Text as text
+from instaui.components.link import Link as link
 
 from instaui.event.web_event import event, WebEvent as TEventFn
 from instaui.event.js_event import js_event
