@@ -6,6 +6,25 @@ from instaui.vars.vue_computed import VueComputed
 
 
 def str_format(template: str, *args, **kwargs):
+    """
+    Formats a string template with positional and keyword arguments.
+
+    Args:
+        template (str): The string template containing {} placeholders for formatting.
+        *args: Variable length positional arguments for positional formatting.
+        **kwargs: Arbitrary keyword arguments for named formatting.
+
+    Example:
+    .. code-block:: python
+        # Positional formatting
+        ui.str_format("pos:a={},b={}", a, b)
+
+        # Index-based positional formatting
+        ui.str_format("num pos:a={0},b={1}", a, b)
+
+        # Named formatting
+        ui.str_format("name pos:b={b},a={a}", a=a, b=b)
+    """
     bindings = {}
     tran_args = []
 
