@@ -66,6 +66,10 @@ class RefBase(
             else [],
         )
 
+    def __deepcopy__(self, memo):
+        memo[id(self)] = self
+        return self
+
     def _to_json_dict(self):
         data = super()._to_json_dict()
         data["id"] = self.__var_tracker.var_id
