@@ -43,6 +43,9 @@ class RefProxy(
     def __ref_(self):
         return super().__getattribute__("_ref_")
 
+    def __deepcopy__(self, memo):
+        return self.__ref_.__deepcopy__(memo)
+
     def __getattribute__(self, name):
         if name not in super().__getattribute__("_prop_names_"):
             return super().__getattribute__(name)
@@ -110,19 +113,58 @@ def state(
     deep_compare: bool = False,
 ) -> _T:
     """
-    Creates a reactive state object that tracks changes and notifies dependencies.
+    Creates a reactive state wrapper that enables automatic UI updates when its value or
+    nested elements change. Supports primitives, lists, dictionaries, and provides
+    reactive operations such as indexing, comparisons, and length evaluation.
 
     Args:
-        value (_T): The initial value to wrap in a reactive state container.
-                   Can be any type (primitive, object, or complex data structure).
+        value (_T): The initial value to be wrapped as a reactive state. Can be any
+            Python type including primitives, lists, or dictionaries.
+        deep_compare (bool): Whether state updates should compare nested values to
+            determine change propagation. Defaults to False.
 
-    # Example:
+    Example:
     .. code-block:: python
-        from instaui import ui,html
-        count = ui.state(0)
+        from instaui import ui, html
 
-        html.number(count)
-        ui.text(count)
+        # Value reactivity
+        s = ui.state('hello')
+        html.input(s)
+        ui.text(s)
+
+
+        # List reactivity
+        items = ui.state([1, 2, 3])
+        html.number(items[0])
+        html.ul.from_list(items)
+
+
+        # Dictionary mutation triggers UI updates
+        data = ui.state({"name": "John"})
+        html.input(data["name"])
+
+
+        # State used with js_computed
+        data = ui.state({"items": [1, 2, 3]})
+        items = ui.js_computed(inputs=[data], code="(d)=> d.items")
+        html.ul.from_list(items)
+
+
+        # Boolean operations maintain reactivity
+        value = ui.state([{"state": True}])
+        html.checkbox(value[0]["state"])
+        html.paragraph(ui.not_(value[0]["state"]))
+
+
+        # String or list length as reactive value
+        text = ui.state("Hello")
+        html.paragraph(ui.str_format("len: {}", ui.len_(text)))
+
+
+        # Comparison operators trigger updates
+        a = ui.state(1)
+        b = ui.state(2)
+        html.paragraph(a < b)  # UI updates when a or b changes
     """
 
     if isinstance(value, RefProxy):
