@@ -1,4 +1,5 @@
 from __future__ import annotations
+from collections.abc import Hashable
 import inspect
 import typing
 from typing_extensions import ParamSpec
@@ -40,6 +41,7 @@ class WebWatch(Jsonable, typing.Generic[P, R]):
         flush: typing.Optional[_types.TFlush] = None,
         pre_setup: typing.Optional[list] = None,
         _debug: typing.Optional[typing.Any] = None,
+        extra_key: typing.Optional[typing.Sequence[Hashable]] = None,
     ) -> None:
         # if pre_setup:
         #     _pre_setup._check_args(pre_setup)
@@ -69,6 +71,7 @@ class WebWatch(Jsonable, typing.Generic[P, R]):
         self._flush = flush
         self._debug = _debug
         self._pre_setup = _pre_setup.convert_list2list(pre_setup)
+        self._extra_key = extra_key
 
     def __call__(self, *args: P.args, **kwargs: P.kwargs) -> R:
         return self._fn(*args, **kwargs)
@@ -82,6 +85,7 @@ class WebWatch(Jsonable, typing.Generic[P, R]):
             hkey = watch_handler.create_handler_key(
                 page_path=app.page_path,
                 handler=self._fn,
+                extra_key=self._extra_key,
             )
 
             watch_handler.register_handler(hkey, self._fn, len(self._outputs))
@@ -132,6 +136,7 @@ def watch(
     once: bool = False,
     flush: typing.Optional[_types.TFlush] = None,
     pre_setup: typing.Optional[list] = None,
+    extra_key: typing.Optional[typing.Sequence[Hashable]] = None,
     _debug: typing.Optional[typing.Any] = None,
 ):
     """
@@ -203,6 +208,7 @@ def watch(
             flush=flush,
             pre_setup=pre_setup,
             _debug=_debug,
+            extra_key=extra_key,
         )
 
         get_current_scope().register_web_watch(obj)
